/*
 * Copyright (C) 2010 Collabora Ltd.
 *   @author Marco Barisione <marco.barisione@collabora.co.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */

#ifndef __RINGTONED_H__
#define __RINGTONED_H__

#ifndef RINGTONED_IS_COMPILING_LIB
#define RINGTONED_IS_COMPILING_LIB
#define MUST_UNDEF_RINGTONED_IS_COMPILING_LIB
#endif

#include <libringtoned/debug.h>
#include <libringtoned/decoder.h>
#include <libringtoned/profile.h>

#ifdef MUST_UNDEF_RINGTONED_IS_COMPILING_LIB
#undef RINGTONED_IS_COMPILING_LIB
#undef MUST_UNDEF_RINGTONED_IS_COMPILING_LIB
#endif

#endif /* __RINGTONED_H__ */
